==> kdenetwork-3.0.1.tar.bz2: kdenetwork-3.0.1/lanbrowsing/kcmlisa/kcmlisa.h <==
/*
 * kcmlisa.h
 *
 * Copyright (c) 2000 Alexander Neundorf <neundorf@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef KCMLISA_H
#define KCMLISA_H

#include <krestrictedline.h>
#include <kconfig.h>

#include <keditlistbox.h>
#include <qvbox.h>

class QPushButton;
class QCheckBox;
class QSpinBox;
class QPushButton;
class KProcess;

class LisaSettings:public QVBox
{
   Q_OBJECT
   public:
      LisaSettings(const QString& config, QWidget *parent=0);
      virtual ~LisaSettings() {};
      void load();
      void save();
   signals:
      void changed();
   protected slots:
      void autoSetup();
      void saveDone(KProcess *);  // called after the kdesud returns (on save)
   protected:
      KConfig m_config;
      QPushButton *m_autoSetup;
      QCheckBox *m_useNmblookup;
      KRestrictedLine *m_pingAddresses;
      KEditListBox *m_pingNames;
      KRestrictedLine *m_allowedAddresses;
      KRestrictedLine *m_broadcastNetwork;
      QSpinBox *m_firstWait;
      QCheckBox *m_secondScan;
      QSpinBox *m_secondWait;
      QSpinBox *m_updatePeriod;
      QCheckBox *m_deliverUnnamedHosts;
      QSpinBox *m_maxPingsAtOnce;

   private:
      QString m_tmpFilename;
      QString m_configFilename;
};

#endif

==> kdenetwork-3.1.4.tar.bz2: kdenetwork-3.1.4/lanbrowsing/kcmlisa/kcmlisa.h <==
/*
 * kcmlisa.h
 *
 * Copyright (c) 2000-2002 Alexander Neundorf <neundorf@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef KCMLISA_H
#define KCMLISA_H

#include <kconfig.h>
#include <kcmodule.h>

class QPushButton;
class QCheckBox;
class QSpinBox;
class QPushButton;
class KProcess;
class KDialogBase;
class KRestrictedLine;
class KEditListBox;
class SetupWizard;

class LisaSettings:public KCModule
{
   Q_OBJECT
   public:
      LisaSettings(const QString& config, QWidget *parent=0);
      virtual ~LisaSettings() {};
      void load();
      void save();
   signals:
      void changed();
   protected slots:
      void slotChanged();
      void autoSetup();
      void saveDone(KProcess *);  // called after the kdesud returns (on save)
      void suggestSettings();
   protected:
      KConfig m_config;
      QPushButton *m_autoSetup;
      QCheckBox *m_useNmblookup;
      QCheckBox *m_sendPings;
      KRestrictedLine *m_pingAddresses;
      KEditListBox *m_pingNames;
      KRestrictedLine *m_allowedAddresses;
      KRestrictedLine *m_broadcastNetwork;
      QSpinBox *m_firstWait;
      QCheckBox *m_secondScan;
      QSpinBox *m_secondWait;
      QSpinBox *m_updatePeriod;
      QCheckBox *m_deliverUnnamedHosts;
      QSpinBox *m_maxPingsAtOnce;
      QPushButton* m_suggestSettings;
      QPushButton *m_advancedSettingsButton;
      KDialogBase *m_lisaAdvancedDlg;

      SetupWizard *m_wizard;
   private:
      QString m_tmpFilename;
      QString m_configFilename;
      bool    m_changed;
};

#endif
